==> rc-select-6.6.1.jar: META-INF/resources/webjars/rc-select/6.6.1/HISTORY.md <==
# History
----
## 6.6.0 / 2016-11-01

- add tokenSeparators for multiple and tag mode

## 6.4.0 / 2016-05-26

- auto expand input in ie10/11 https://github.com/react-component/select/pull/93
- realign when value change. https://github.com/react-component/select/pull/92

## 6.3.0 / 2016-04-28

- support onBlur

## 6.2.0 / 2016-04-20

- remove searchPlaceholder

## 6.1.0 / 2016-04-18

- go with http://semantic-ui.com/modules/dropdown.html#search-selection

## 6.0.0 / 2016-03-16

- remove defaultLabel/label
- add labelInValue prop to control label
- support dropdownAlign

## 5.8.0 / 2016-01-11

- support value type to be number

## 5.7.0 / 2016-01-06

- add getPopupContainer prop

## 5.6.0 / 2016-01-01

- scroll to active item when open menu on single mode

## 5.5.0 / 2015-12-22

- add defaultActiveFirstOption prop

## 5.4.0 / 2015-12-01

- fix disabled for old ie

## 5.3.0 / 2015-11-30

- add choiceTransitionName prop

## 5.2.0 / 2015-11-24

- do not hide dropdown on multiple or tag mode

## 5.0.0 / 2015-10-22

- only support react 0.14+
- auto adjust position if visible region is not enough

## 4.9.0 / 2015-09-10

- add label for onChange listener

## 4.8.0 / 2015-08-20

- make value a controlled value
- add defaultValue prop
- remove renderDropdownToBody prop. defaults to true

## 4.7.0 / 2015-08-18

implement searchPlaceholder to prevent bug for ie10

## 4.5.0 / 2015-07-30

use rc-animate & rc-align. (assets change)

## 4.4.0 / 2015-07-15

`new` support dropdownStyle dropdownMenuStyle prop

## 4.3.0 / 2015-07-14

`new` [#17](https://github.com/react-component/select/issues/17) support render dropdown to body

## 4.2.0 / 2015-07-07

`improved` [#15](https://github.com/react-component/select/issues/15) fix input in multiple mode

## 4.1.0 / 2015-07-01

`new` [#13](https://github.com/react-component/select/issues/13) add maxTagTextLength

## 4.0.0 / 2015-06-26

https://github.com/react-component/select/issues/11

## 3.5.0 / 2015-06-17

`new` [#6](https://github.com/react-component/select/issues/6) add OptGroup


## 3.4.0 / 2015-06-15

`new` support showSearch/animation/transitionName/disabled props

## 3.1.0 / 2015-03-23

`new` [#2](https://github.com/react-component/select/pull/2) support tags config

==> rc-select-6.8.0.jar: META-INF/resources/webjars/rc-select/6.8.0/HISTORY.md <==
# History
----
## 6.8.0 / 2017-03-24

- support allowClear in multiple/tags mode

## 6.7.0 / 2017-01-03

- support getInputElement https://github.com/react-component/select/pull/145

## 6.6.0 / 2016-11-01

- add tokenSeparators for multiple and tag mode

## 6.4.0 / 2016-05-26

- auto expand input in ie10/11 https://github.com/react-component/select/pull/93
- realign when value change. https://github.com/react-component/select/pull/92

## 6.3.0 / 2016-04-28

- support onBlur

## 6.2.0 / 2016-04-20

- remove searchPlaceholder

## 6.1.0 / 2016-04-18

- go with http://semantic-ui.com/modules/dropdown.html#search-selection

## 6.0.0 / 2016-03-16

- remove defaultLabel/label
- add labelInValue prop to control label
- support dropdownAlign

## 5.8.0 / 2016-01-11

- support value type to be number

## 5.7.0 / 2016-01-06

- add getPopupContainer prop

## 5.6.0 / 2016-01-01

- scroll to active item when open menu on single mode

## 5.5.0 / 2015-12-22

- add defaultActiveFirstOption prop

## 5.4.0 / 2015-12-01

- fix disabled for old ie

## 5.3.0 / 2015-11-30

- add choiceTransitionName prop

## 5.2.0 / 2015-11-24

- do not hide dropdown on multiple or tag mode

## 5.0.0 / 2015-10-22

- only support react 0.14+
- auto adjust position if visible region is not enough

## 4.9.0 / 2015-09-10

- add label for onChange listener

## 4.8.0 / 2015-08-20

- make value a controlled value
- add defaultValue prop
- remove renderDropdownToBody prop. defaults to true

## 4.7.0 / 2015-08-18

implement searchPlaceholder to prevent bug for ie10

## 4.5.0 / 2015-07-30

use rc-animate & rc-align. (assets change)

## 4.4.0 / 2015-07-15

`new` support dropdownStyle dropdownMenuStyle prop

## 4.3.0 / 2015-07-14

`new` [#17](https://github.com/react-component/select/issues/17) support render dropdown to body

## 4.2.0 / 2015-07-07

`improved` [#15](https://github.com/react-component/select/issues/15) fix input in multiple mode

## 4.1.0 / 2015-07-01

`new` [#13](https://github.com/react-component/select/issues/13) add maxTagTextLength

## 4.0.0 / 2015-06-26

https://github.com/react-component/select/issues/11

## 3.5.0 / 2015-06-17

`new` [#6](https://github.com/react-component/select/issues/6) add OptGroup


## 3.4.0 / 2015-06-15

`new` support showSearch/animation/transitionName/disabled props

## 3.1.0 / 2015-03-23

`new` [#2](https://github.com/react-component/select/pull/2) support tags config
